==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/controllers/personalpassword.php <==
<?php
/**
 * UTF8
 * pavel.rudol, 2.10.2018
 */

namespace Ron\RonPortal;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\InternalRedirect;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\MVC\TextViewObject;
use Ron\MVC\HttpController;
use Ron\TextManager;


class PersonalPasswordController extends HttpController
{
    /** @var PravaNaOsoby */
    private $prava;

    /** @var Database */
    private $database;


    /**
     * @param Database $database
     */
    public function __construct($database)
    {
        Prava::nastavObdobiProPrava(DateUtils::today());
        $this->prava = Prava::vratPrava('osobni_heslo');

        $this->database = $database;
    }

    private function jeNastaveneHeslo()
    {
        $params = $this->database->createParameters();

        $sql =
            "SELECT OsobniHeslo FROM Osoba WHERE RC = " . $params->addParameter(User::getRC());

        $cursor = $this->database->getSqlResult($sql, $params);

        $row = $cursor->fetch();

        if (is_null($row[0]))
            return false;

        return true;
    }


    /**
     * @param $heslo
     * @return string
     * @throws \Exception
     */
    private function zakodujHeslo($heslo)
    {
        require_once('adsapp/agentmanager.php');
        $agentResult = AgentManager::executePersonAgent("100 -vstup:$heslo -nolog", false);

        if (is_null($agentResult)) {
            throw new \Exception(TextManager::_('Heslo_nezakodovano'));
        }

        return $agentResult->resultParams['heslo'];
    }

    /**
     * @param $heslo
     * @throws \Exception
     */
    private function overHeslo($heslo)
    {
        if (is_null($heslo)) {
            throw new \Exception( \Ron\ronText('Spatne_puvodni_heslo') );
        }

        $heslo = hex2bin($this->zakodujHeslo($heslo));

        $params = $this->database->createParameters();

        $sql =
            "SELECT RC FROM Osoba WHERE RC = " . $params->addParameter(User::getRC()) . " AND OsobniHeslo = " . $params->addParameter($heslo);

        $cursor = $this->database->getSqlResult($sql, $params);

        if (!($row = $cursor->fetch()))
            throw new \Exception( \Ron\ronText('Spatne_puvodni_heslo') );
    }

    /**
     * @param string $newpass1
     * @param string $newpass2
     * @param string|null $oldpass
     * @param string|null $osoba
     * @return bool
     * @throws \Exception
     */
    function setPassword($newpass1, $newpass2, $oldpass = null, $osoba = null)
    {
        if ($newpass1 != $newpass2) {
            throw new \Exception( \Ron\ronText('Hesla_se_neshoduji') );
        }

        if ($this->prava->prava == 1) {
            if ($this->jeNastaveneHeslo())
                $this->overHeslo($oldpass);
            $osobaRC = User::getRC();
        } else {
            require_once('adsapp/ppomer.php');
            $pracPomer = new PracovniPomer();
            $pracPomer->nactiPPPodleId($this->database, $osoba);

            if (!$this->prava->lzeZobrazitRC($pracPomer->rc)) {
                RonPortalUtils::neniPravoException();
            }
            $osobaRC = $pracPomer->rc;
        }

        $newpass1 = hex2bin($this->zakodujHeslo($newpass1));

        $params = $this ->database ->createParameters();

        $this ->database ->sql(
                'UPDATE Osoba SET OsobniHeslo = ' . $params->addParameter($this->database->getBlobParam($newpass1)) .
                ' WHERE RC = ' . $params->addParameter($osobaRC), $params);

        return true;
    }


    /**
     * @return bool|Redirect|string
     */
    function handleChangePassword()
    {
        if (isset($_POST['setpassword'])  &&  $_POST['setpassword']) {
            try {
                $this ->setPassword($_POST['newpass1'], $_POST['newpass2'], $_POST['oldpass'], $_POST['osoba']);
                return new Redirect(null, '?menuid=personalpassword&set=1');
            } catch (\Exception $e) {
                MessageManager::addErrorMessage($e ->getMessage());
                // pokracuje dale (zobrazi znovu dialog)
            }
        } else {
            if (isset($_GET['set'])  &&  $_GET['set']) {
                return new TextViewObject(
                    \Ron\ronText('Heslo_zmeneno') .
                    '<br/><br/>' .
                    "<a href='?menuid=vyplatnilistky'>" . \Ron\ronText('Pokracovat') . "</a>\n"
                );
            }
        }

        if ($this->prava->prava != 1) {
            require_once('adsapp/ronportalcontrols.php');
            $combo = new ComboBoxOsoba();
            $combo->loadDataPP($this->database, DateUtils::today(), DateUtils::today(), $this->prava, null, null);

            Model::addData('osoba', $combo);
        } else {
            Model::addData('vyzadovatpuvodni', $this->jeNastaveneHeslo());
        }

        return new BaseViewObject('view/personal_password.php');
    }


    /**
     * @param string $action
     * @return string|Redirect|InternalRedirect
     * @throws \Exception
     */
    public function handleAction($action)
    {
        if (!$this->prava->jsouNejakePrava())
            RonPortalUtils::neniPravoException();

        TextManager::getInstance() ->loadStrings('users.ini');

        return $this ->handleChangePassword();
    }


}

return new PersonalPasswordController($this->database);

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/controllers/personalpassword.php <==
<?php
/**
 * UTF8
 * pavel.rudol, 2.10.2018
 */

namespace RonPortal;

use Exception;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\InternalRedirect;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\MVC\TextViewObject;
use Ron\MVC\HttpController;
use Ron\TextManager;
use RonPortal\Controls\ComboBoxOsoba;
use RonPortal\System\AgentManager;
use function Ron\ronText;


class PersonalPasswordController extends HttpController
{
    /** @var PravaNaOsoby */
    private $prava;

    /** @var Database */
    private $database;


    /**
     * @param Database $database
     */
    public function __construct($database)
    {
        Prava::nastavObdobiProPrava(DateUtils::today());
        $this->prava = Prava::vratPrava('osobni_heslo');

        $this->database = $database;
    }

    private function jeNastaveneHeslo()
    {
        $params = $this->database->createParameters();

        $sql =
            "SELECT OsobniHeslo FROM Osoba WHERE RC = " . $params->addParameter(User::getRC());

        $cursor = $this->database->getSqlResult($sql, $params);

        $row = $cursor->fetch();

        if (is_null($row[0]))
            return false;

        return true;
    }


    /**
     * @param $heslo
     * @return string
     * @throws Exception
     */
    private function zakodujHeslo($heslo)
    {
        $agentResult = AgentManager::executePersonAgent("100 -vstup:$heslo ", false); //-nolog

        if (is_null($agentResult)) {
            throw new Exception(TextManager::_('Heslo_nezakodovano'));
        }

        return $agentResult->resultParams['heslo'];
    }

    /**
     * @param $heslo
     * @throws Exception
     */
    private function overHeslo($heslo)
    {
        if (is_null($heslo)) {
            throw new Exception( ronText('Spatne_puvodni_heslo') );
        }

        $heslo = $this->zakodujHeslo($heslo);

        $params = $this->database->createParameters();

        $sql =
            "SELECT RC FROM Osoba WHERE RC = " . $params->addParameter(User::getRC()) . " AND OsobniHeslo = " . $params->addParameter($heslo);

        $cursor = $this->database->getSqlResult($sql, $params);

        if (!($cursor->fetch()))
            throw new Exception( ronText('Spatne_puvodni_heslo') );
    }

    /**
     * @param string $newpass1
     * @param string $newpass2
     * @param string|null $oldpass
     * @param string|null $osoba
     * @return bool
     * @throws Exception
     */
    function setPassword($newpass1, $newpass2, $oldpass = null, $osoba = null)
    {
        if ($newpass1 != $newpass2) {
            throw new Exception( ronText('Hesla_se_neshoduji') );
        }

        if ($this->prava->prava == 1) {
            if ($this->jeNastaveneHeslo())
                $this->overHeslo($oldpass);
            $osobaRC = User::getRC();
        } else {
            $pracPomer = new PracovniPomer();
            $pracPomer->nactiPPPodleId($this->database, $osoba);

            if (!$this->prava->lzeZobrazitRC($pracPomer->rc)) {
                throw new NeniPravoException();
            }
            $osobaRC = $pracPomer->rc;
        }

        $newpass1 = $this->zakodujHeslo($newpass1);

        $params = $this ->database ->createParameters();

        $this ->database ->sql(
                'UPDATE Osoba SET OsobniHeslo = ' . $params->addParameter($this->database->getBlobParam($newpass1, 'OsobniHeslo')) .
                ' WHERE RC = ' . $params->addParameter($osobaRC), $params);

        return true;
    }


    /**
     * @return bool|BaseViewObject|Redirect|TextViewObject|string
     */
    function handleChangePassword()
    {
        if (isset($_POST['setpassword'])  &&  $_POST['setpassword']) {
            try {
                $this ->setPassword($_POST['newpass1'], $_POST['newpass2'], $_POST['oldpass'], isset($_POST['osoba']) ? $_POST['osoba'] : null);
                return new Redirect(null, '?menuid=personalpassword&set=1');
            } catch (Exception $e) {
                MessageManager::addErrorMessage($e ->getMessage());
                // pokracuje dale (zobrazi znovu dialog)
            }
        } else {
            if (isset($_GET['set'])  &&  $_GET['set']) {
                return new TextViewObject(
                    ronText('Heslo_zmeneno') .
                    '<br/><br/>' .
                    "<a href='?menuid=vyplatnilistky'>" . ronText('Pokracovat') . "</a>\n"
                );
            }
        }

        if ($this->prava->prava != 1) {
            $combo = new ComboBoxOsoba();
            $combo->loadDataPP($this->database, DateUtils::today(), DateUtils::today(), $this->prava, null, null);

            Model::addData('osoba', $combo);
        } else {
            Model::addData('vyzadovatpuvodni', $this->jeNastaveneHeslo());
        }

        return new BaseViewObject('view/personal_password.php');
    }


    /**
     * @param string $action
     * @return string|Redirect|InternalRedirect
     * @throws Exception
     */
    public function handleAction($action)
    {
        if (!$this->prava->jsouNejakePrava())
            throw new NeniPravoException();

        TextManager::getInstance() ->loadStrings('users.ini');

        return $this ->handleChangePassword();
    }


}

return new PersonalPasswordController($this->database);
